@@ -1,4 +1,5 @@
 import os
+import shutil
 import sys
 import json
 import logging
@@ -7,7 +8,10 @@ import datetime
 from collections import OrderedDict
 
 import boto3
+import joblib
 from hdfs3 import HDFileSystem
+
+from Accuinsight.Lifecycle.utils import load_model
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.core.LcConst.LcConst import ENV_JUPYTER_HOME_DIR
 from Accuinsight.modeler.utils.runs_utils import ProgressPercentage
@@ -121,6 +125,7 @@ class Common(object):
             self.StorageInfo = self.storage_info_from_set
             self.target_name = target
 
+        # save_json 만 True로 하고 사용자가 파라미터로 save_path를 입력하지 않을 경우
         if save_json:
             if save_path is None:
                 timestamp = str(datetime.datetime.now().date()).replace('-', '')
@@ -272,6 +277,9 @@ class Common(object):
         if data is not None:
             self.data = data
 
+    def unset_data(self):
+        self.data = None
+
     @staticmethod
     def _send_message(metric=None, current_value=None, message=None, thresholds=None, alarm_object=None, alarm_api=None):
         if alarm_object:
@@ -349,3 +357,55 @@ class Common(object):
 
     def get_current_notebook(self):
         return self.notebook_info
+
+    @staticmethod
+    def set_runtime_model(framework, run_id=None):
+        if framework == 'sklearn':
+            if run_id:
+                export_path = ENV_JUPYTER_HOME_DIR + '/airuntime/' + framework + '/models'
+                shutil.rmtree(export_path)
+                os.mkdir(export_path)
+                joblib.dump(load_model(run_id), export_path + '/model.joblib')
+            else:
+                with open(ENV_JUPYTER_HOME_DIR + '/runs/run_info.json') as f:
+                    json_object = json.load(f)
+
+                try:
+                    shutil.copyfile(ENV_JUPYTER_HOME_DIR + '/' + json_object['save_best_model_joblib_path'],
+                                    ENV_JUPYTER_HOME_DIR + '/airuntime/' + framework + '/models/model.joblib')
+                except TypeError:
+                    raise ValueError('최근에 실행된 experiment가 ML 모델이 아닙니다.')
+
+        elif framework == 'tensorflow' or framework == 'keras':
+            if run_id:
+                if framework == 'keras':
+                    framework = 'tensorflow'
+
+                saved_model = load_model(run_id)
+
+            else:
+                with open(ENV_JUPYTER_HOME_DIR + '/runs/run_info.json') as f:
+                    json_object = json.load(f)
+
+                try:
+                    with open(ENV_JUPYTER_HOME_DIR + '/' + json_object['save_best_model_json_path'], 'r') as f:
+                        saved_model_json = f.read()
+                except TypeError:
+                    raise ValueError('최근에 실행된 experiment가 DL 모델이 아닙니다.')
+
+                if framework == 'keras':
+                    from keras.models import model_from_json
+                    saved_model = model_from_json(saved_model_json)
+                    framework = 'tensorflow'
+                else:
+                    from tensorflow.keras.models import model_from_json
+                    saved_model = model_from_json(saved_model_json)
+
+                # load weights into new model
+                saved_model.load_weights(ENV_JUPYTER_HOME_DIR + '/' + json_object['save_best_model_h5_path'])
+
+            export_path = ENV_JUPYTER_HOME_DIR + '/airuntime/' + framework + '/models'
+            shutil.rmtree(export_path)
+            saved_model.save(export_path + '/1', save_format='tf')
+        else:
+            raise ValueError("잘못된 framework 값이 입력되었습니다. framework가 가질 수 있는 값은 sklearn/tensorflow/keras 입니다.")
