@@ -51,11 +51,11 @@ class accuinsight(Common):
         except TypeError or KeyError:
             return None
 
-    def autolog(self, tag=None, best_weights=False, model_monitor=False):
+    def autolog(self, tag=None, best_weights=False, model_monitor=False, runtime=False):
         global description, endpoint, var_model_file_path, message, thresholds, best_weights_on, run_id, alarm, alarm_api, shap_on, feature_name, run_meta
         description = tag
         endpoint = self.endpoint
-        message = self.message
+        message = self.message # common.py send_message 호출을 통해 생성
         thresholds = self.thresholds
         alarm = self.workspace_alarm
         alarm_api = self.workspace_alarm_api
@@ -275,6 +275,8 @@ class accuinsight(Common):
                                                 env_value[LcConst.BACK_END_API_PORT],
                                                 env_value[LcConst.BACK_END_API_URI])
                 modeler_rest.lc_create_run(run_meta)
+                if runtime:
+                    accuinsight.set_runtime_model('tensorflow')
                 accuinsight._off_autolog()
 
         class visualCallbacks(tensorflow.keras.callbacks.Callback):
