@@ -5,7 +5,7 @@ Classify the model type to Tree(ensemble) based model and linear model.
 
 Tree_type_1 = ['AdaBoost', 'Bagging', 'ExtraTrees', 'GradientBoosing', 'IsolationForest', 'RandomForest',
         'catboost', 'xgboost','HistGradientBoosting', 'DecisionTree',
-        'ExtraTree', 'XGBRegressor', 'XGBClassifier']
+        'ExtraTree', 'XGBRegressor', 'XGBClassifier', 'XGB_Regressor', 'XGB_Classifier']
 
 Tree_type_2 = ['LightGBM', 'lightgbm']
 
