@@ -5,7 +5,7 @@ Classify available models to regression and classification.
 reference: https://scikit-learn.org/stable/index.html
 '''
 
-REGRESSION = ['Regressor', 'Ridge', 'Lasso', 'ElasticNet', 'Lars', 'SVR', 'OrthogonalMatchingPursuit']
+REGRESSION = ['Regressor', 'Ridge', 'Lasso', 'ElasticNet', 'Lars', 'SVR', 'OrthogonalMatchingPursuit', 'Regression']
 CLASSIFICATION = ['Classifier', 'Logistic', 'SVC', 'NB', 'Perceptron']
 ONEVS = ['OneVsRest', 'OneVsOne']
 
