@@ -620,15 +620,17 @@ def is_local_source(filename, modname, experiment_path):
 
 
 def get_main_file(globs, save_git_info):
-    filename = globs.get("__file__")
-
-    if filename is None:
-        experiment_path = os.path.abspath(os.path.curdir)
-        main = None
-    else:
-        main = Source.create(globs.get("__file__"), save_git_info)
-        experiment_path = os.path.dirname(main.filename)
-        main.to_json()
+    experiment_path = os.path.abspath(os.path.curdir)
+    main = None
+    # filename = globs.get("__file__")
+    #
+    # if filename is None:
+    #     experiment_path = os.path.abspath(os.path.curdir)
+    #     main = None
+    # else:
+    #     main = Source.create(globs.get("__file__"), save_git_info)
+    #     experiment_path = os.path.dirname(main.filename)
+    #     main.to_json()
 
     return experiment_path, main
 
