@@ -13,22 +13,22 @@ def get_os_env(env_type='LC', env_path=None, env_file=None):
 
     env_value = {}
     if env_path is None:
-        env_path = '/Users/a10053'
+        env_path = '/usr'
     if env_file is None:
-        env_file = '.env'
+        env_file = '.accu_env'
 
     env_file = open(env_path + '/' + env_file, 'r')
     while True:
         line = env_file.readline()
         if not line:
             break
-        if line:
-            if _ENV_PREFIX in line:
-                key, value = line.split('=')
-                if key is not None:
-                    if _ENV_PREFIX in key:
-                        value = value.rstrip()
-                        env_value.setdefault(key, value)
+
+        if _ENV_PREFIX in line:
+            key, value = line.split('=')
+            if key is not None:
+                if _ENV_PREFIX in key:
+                    value = value.rstrip()
+                    env_value.setdefault(key, value)
 
     return env_value
 
@@ -42,18 +42,30 @@ def get_current_notebook():
         target_path = LcConst.ENV_JUPYTER_WORKSPACE
         # '/home/notebook/.jupyter/lab/workspaces'
         if os.path.isdir(target_path):  # if jupyter lab
-            file_lists = list()
+            file_lists = dict()
             file_name = None
             for (dir_path, dir_names, file_names) in os.walk(target_path):
                 for fn in file_names:
+                    #                    print(fn)
+                    #                    print(": ",os.path.getmtime(target_path+"/"+fn))
                     if not fn.endswith('.swp'):
-                        if 'default' in fn:
-                            file_name = fn
-                            break
-                        file_lists.append(fn)
-
-            if not file_name:
-                file_name = file_lists[0]
+                        file_lists[fn] = os.path.getmtime(target_path + "/" + fn)
+            print(file_lists)
+            sorted_file_lists_modified = sorted(file_lists.items(), key=lambda item: item[1], reverse=True)
+            print(sorted_file_lists_modified)
+            file_name = sorted_file_lists_modified[0][0]
+            print(file_name)
+            # 원본 소스
+            # for (dir_path, dir_names, file_names) in os.walk(target_path):
+            #     for fn in file_names:
+            #         if not fn.endswith('.swp'):
+            #             if 'default' in fn:
+            #                 file_name = fn
+            #                 break
+            #             file_lists.append(fn)
+            #
+            # if not file_name:
+            #     file_name = file_lists[0]
 
             with open(target_path + '/' + file_name, 'r') as tf:
                 strlines = tf.readlines()
